package LibraryManagement;

import java.util.ArrayList;
import java.util.List;


public class Library {
    private List<Book> books;
    private List<Member> members;
    private List<Loan> loans;

    public Library() {
        this.books = new ArrayList<>();
        this.members = new ArrayList<>();
        this.loans = new ArrayList<>();
    }

    public void addBook(Book book) {
        books.add(book);
    }

    public void addMember(Member member) {
        members.add(member);
    }

    public void loanBook(Book book, Member member) throws Exception {
        if (!books.contains(book)) {
            throw new Exception("Book not in library");
        }
        if (!members.contains(member)) {
            throw new Exception("Member not registered");
        }
        if (book.isLoaned()) {
            throw new Exception("Book already loaned");
        }
        Loan loan = new Loan(book, member);
        loans.add(loan);
        book.setLoaned(true);
    }

    public void returnBook(Book book) throws Exception {
        if (!books.contains(book)) {
            throw new Exception("Book not in library");
        }
        Loan loan = loans.stream().filter(l -> l.getBook().equals(book)).findFirst().orElse(null);
        if (loan == null) {
            throw new Exception("Book not loaned");
        }
        loans.remove(loan);
        book.setLoaned(false);
    }

    public List<Book> getBooks() {
        return books;
    }

    public List<Member> getMembers() {
        return members;
    }

    public List<Loan> getLoans() {
        return loans;
    }
}